==> ah-formbuilder-1.0.61.tgz: package/es/components/toolbar/field-forms/Image.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, deleteNewField as _deleteNewField, updateField as _updateField } from '../../../actions/formActions';
import { connect } from "react-redux";
import FileUpload from "../../../utils/file-upload";
import TextInput from "../../../utils/inputs/TextInput";
import { Scrollbars } from 'react-custom-scrollbars';
import FormHelperText from '@material-ui/core/FormHelperText';
import { getHeight } from '../../../utils/helpers';
import { processLocalFields } from './utils/helpers';
import { selectFieldsConfigs } from './utils/selectFieldConfigs';
import FieldRenderer from './utils/FieldRenderer';
import axios from "axios";
import { imageFieldsConfigs } from './utils/imageFieldConfigs';
var urlLabel = {
  en: 'Url',
  ar: 'عنوان url'
};
var orLabel = {
  en: 'OR',
  ar: 'أو'
};
var uploadLabel = {
  en: 'File Upload',
  ar: 'تحميل الملف'
};
var cancelLabel = {
  en: 'Cancel',
  ar: 'إلغاء'
};
var saveLabel = {
  en: 'Save',
  ar: 'حفظ'
};

var Image = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Image, _React$Component);

  function Image(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      _this.setState(_extends({}, _this.state, {
        isSaving: true
      }));

      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          subType = _this$state.subType,
          uuid = _this$state.uuid,
          type = _this$state.type,
          url = _this$state.url,
          href = _this$state.href,
          tooltip = _this$state.tooltip,
          visibility = _this$state.visibility,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          subType: subType,
          url: url,
          href: href,
          tooltip: tooltip,
          visibility: visibility
        }
      };
      var data = {
        field: newField
      };
      newField.locals = processLocalFields(_this.props.locals, _this.state);
      data.locals = processLocalFields(_this.props.locals, _this.state);
      ValidateField(newField, null, _this.props.currentLang).then( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _this.props.updateField(newField);

                _context.next = 3;
                return axios.post(_this.props.predefinedEndpoint + "/form/field/" + _this.props.formId, data);

              case 3:
                _this.props.disableFieldEdit();

                _this.setState(_extends({}, _this.state, {
                  isSaving: false
                }));

              case 5:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      })))["catch"](function (err) {
        _this.setState({
          errors: err,
          isSaving: false
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "renderFields", function () {
      return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-mb-4"
      }, /*#__PURE__*/React.createElement(TextInput, {
        label: urlLabel[_this.props.currentLang],
        value: _this.state.url,
        handleChange: function handleChange(e) {
          return _this.handleDataChange(e.target.value, 'url');
        },
        autoFocus: true,
        error: _this.state.errors.url
      })), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-separator ahfb-mb-4"
      }, /*#__PURE__*/React.createElement("span", null, orLabel[_this.props.currentLang])), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-mb-4"
      }, /*#__PURE__*/React.createElement(FileUpload, {
        label: uploadLabel[_this.props.currentLang],
        fileUploadUrl: _this.props.fileUploadUrl,
        url: _this.state.url,
        updateUrl: function updateUrl(url) {
          return _this.handleDataChange(url, 'url');
        },
        variant: "images",
        uploadable: true
      }), _this.state.errors.upload ? /*#__PURE__*/React.createElement(FormHelperText, {
        error: true
      }, _this.state.errors.upload) : ""), /*#__PURE__*/React.createElement(FieldRenderer, _extends({}, _this.state, {
        locals: _this.props.locals,
        fieldConfigs: imageFieldsConfigs,
        handleDataChange: _this.handleDataChange
      })));
    });

    _this.state = _extends({
      uploading: false,
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName,
      isSaving: false
    }, props.data.config);
    return _this;
  }

  var _proto = Image.prototype;

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.data.uuid !== this.state.uuid) {
      this.setState(_extends({
        uploading: false,
        errors: {},
        uuid: nextProps.data.uuid,
        name: nextProps.data.name,
        type: nextProps.data.type,
        order: nextProps.data.order,
        parentId: nextProps.data.parentId,
        machineName: nextProps.data.machineName,
        isSaving: false
      }, nextProps.data.config));
    }
  };

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, false)
      },
      autoHide: true
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-p-3 ahfb-my-3"
    }, this.renderFields(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right"
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      className: "ahfb-mr-2",
      onClick: this.cancelEdit
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      disableElevation: true,
      disabled: this.state.isSaving,
      onClick: this.saveField
    }, saveLabel[this.props.currentLang])))));
  };

  return Image;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    fileUploadUrl: state.form.fileUploadUrl,
    locals: state.form.locals,
    formId: state.form.formId,
    predefinedEndpoint: state.form.predefinedEndpoint,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Image);

==> ah-formbuilder-1.0.92.tgz: package/es/components/toolbar/field-forms/Image.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
var _jsxFileName = "/home/zaman/Documents/GitLab/bayt/formbuilder/src/components/toolbar/field-forms/Image.js";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, deleteNewField as _deleteNewField, updateField as _updateField } from '../../../actions/formActions';
import { connect } from "react-redux";
import FileUpload from "../../../utils/file-upload";
import TextInput from "../../../utils/inputs/TextInput";
import { Scrollbars } from 'react-custom-scrollbars';
import FormHelperText from '@material-ui/core/FormHelperText';
import { getHeight } from '../../../utils/helpers';
import { processLocalFields } from './utils/helpers';
import { selectFieldsConfigs } from './utils/selectFieldConfigs';
import FieldRenderer from './utils/FieldRenderer';
import axios from "axios";
import { imageFieldsConfigs } from './utils/imageFieldConfigs';
var urlLabel = {
  en: 'Url',
  ar: 'عنوان url'
};
var orLabel = {
  en: 'OR',
  ar: 'أو'
};
var uploadLabel = {
  en: 'File Upload',
  ar: 'تحميل الملف'
};
var cancelLabel = {
  en: 'Cancel',
  ar: 'إلغاء'
};
var saveLabel = {
  en: 'Save',
  ar: 'حفظ'
};

var Image = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Image, _React$Component);

  function Image(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      _this.setState(_extends({}, _this.state, {
        isSaving: true
      }));

      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          subType = _this$state.subType,
          uuid = _this$state.uuid,
          type = _this$state.type,
          url = _this$state.url,
          href = _this$state.href,
          tooltip = _this$state.tooltip,
          visibility = _this$state.visibility,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          subType: subType,
          url: url,
          href: href,
          tooltip: tooltip,
          visibility: visibility
        }
      };
      var data = {
        field: newField
      };
      newField.locals = processLocalFields(_this.props.locals, _this.state);
      data.locals = processLocalFields(_this.props.locals, _this.state);
      ValidateField(newField, null, _this.props.currentLang).then( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _this.props.updateField(newField);

                _context.next = 3;
                return axios.post(_this.props.predefinedEndpoint + "/form/field/" + _this.props.formId, data);

              case 3:
                _this.props.disableFieldEdit();

                _this.setState(_extends({}, _this.state, {
                  isSaving: false
                }));

              case 5:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      })))["catch"](function (err) {
        _this.setState({
          errors: err,
          isSaving: false
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "renderFields", function () {
      return /*#__PURE__*/React.createElement("div", {
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 114,
          columnNumber: 7
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 115,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(TextInput, {
        label: urlLabel[_this.props.currentLang],
        value: _this.state.url,
        handleChange: function handleChange(e) {
          return _this.handleDataChange(e.target.value, 'url');
        },
        autoFocus: true,
        error: _this.state.errors.url,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 116,
          columnNumber: 11
        }
      })), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-separator ahfb-mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 118,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("span", {
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 118,
          columnNumber: 51
        }
      }, orLabel[_this.props.currentLang])), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-mb-4",
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 119,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(FileUpload, {
        label: uploadLabel[_this.props.currentLang],
        fileUploadUrl: _this.props.fileUploadUrl,
        url: _this.state.url,
        updateUrl: function updateUrl(url) {
          return _this.handleDataChange(url, 'url');
        },
        variant: "images",
        uploadable: true,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 120,
          columnNumber: 11
        }
      }), _this.state.errors.upload ? /*#__PURE__*/React.createElement(FormHelperText, {
        error: true,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 122,
          columnNumber: 13
        }
      }, _this.state.errors.upload) : ""), /*#__PURE__*/React.createElement(FieldRenderer, _extends({}, _this.state, {
        locals: _this.props.locals,
        fieldConfigs: imageFieldsConfigs,
        handleDataChange: _this.handleDataChange,
        __self: _assertThisInitialized(_this),
        __source: {
          fileName: _jsxFileName,
          lineNumber: 125,
          columnNumber: 9
        }
      })));
    });

    _this.state = _extends({
      uploading: false,
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName,
      isSaving: false
    }, props.data.config);
    return _this;
  }

  var _proto = Image.prototype;

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.data.uuid !== this.state.uuid) {
      this.setState(_extends({
        uploading: false,
        errors: {},
        uuid: nextProps.data.uuid,
        name: nextProps.data.name,
        type: nextProps.data.type,
        order: nextProps.data.order,
        parentId: nextProps.data.parentId,
        machineName: nextProps.data.machineName,
        isSaving: false
      }, nextProps.data.config));
    }
  };

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 143,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, false)
      },
      autoHide: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 144,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-p-3 ahfb-my-3",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 145,
        columnNumber: 11
      }
    }, this.renderFields(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 147,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      className: "ahfb-mr-2",
      onClick: this.cancelEdit,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 148,
        columnNumber: 15
      }
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      disableElevation: true,
      disabled: this.state.isSaving,
      onClick: this.saveField,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 151,
        columnNumber: 15
      }
    }, saveLabel[this.props.currentLang])))));
  };

  return Image;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    fileUploadUrl: state.form.fileUploadUrl,
    locals: state.form.locals,
    formId: state.form.formId,
    predefinedEndpoint: state.form.predefinedEndpoint,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Image);
